@@ -39,6 +39,8 @@ pub struct Settings {
     pub prompt: Prompt,
     #[serde(default)]
     pub behavior: Behavior,
+    #[serde(default)]
+    pub hooks: Hooks,
 }
 
 impl Settings {
@@ -146,7 +148,9 @@ impl Default for Prompt {
 #[derive(Debug, Clone, clap::ValueEnum, Deserialize)]
 #[clap(rename_all = "lower")]
 #[serde(rename_all = "lowercase")]
+#[derive(Default)]
 pub enum ContextHeaderBehavior {
+    #[default]
     Auto,
     Always,
     Never,
@@ -162,12 +166,6 @@ impl ContextHeaderBehavior {
     }
 }
 
-impl Default for ContextHeaderBehavior {
-    fn default() -> Self {
-        ContextHeaderBehavior::Auto
-    }
-}
-
 #[derive(Debug, Deserialize)]
 pub struct Behavior {
     #[serde(default = "def_bool_true")]
@@ -185,6 +183,14 @@ impl Default for Behavior {
     }
 }
 
+#[derive(Debug, Deserialize, Default)]
+pub struct Hooks {
+    #[serde(default)]
+    pub start_ctx: String,
+    #[serde(default)]
+    pub stop_ctx: String,
+}
+
 fn def_bool_true() -> bool {
     true
 }
